@@ -1,4 +1,4 @@
-from typing import List, Optional
+from __future__ import annotations
 
 from pythonbible.books import Book
 from pythonbible.normalized_reference import NormalizedReference
@@ -12,7 +12,7 @@ from pythonbible.verses import (
 
 def is_valid_verse_id(verse_id: int) -> bool:
     """
-    Checks to see if the given verse_id corresponds to a valid verse in the Bible
+    Check to see if the given verse_id corresponds to a valid verse in the Bible.
 
     :param verse_id: a verse id
     :type verse_id: int
@@ -24,7 +24,8 @@ def is_valid_verse_id(verse_id: int) -> bool:
 
 def is_valid_reference(reference: NormalizedReference) -> bool:
     """
-    Checks to see if the given NormalizedReference is a valid scripture reference
+    Check to see if the given NormalizedReference is a valid scripture reference.
+
     (i.e. all of the verses in the reference are valid verses)
 
     :param reference: a normalized reference
@@ -36,7 +37,9 @@ def is_valid_reference(reference: NormalizedReference) -> bool:
         return False
 
     if not is_valid_verse(
-        reference.book, reference.start_chapter, reference.start_verse
+        reference.book,
+        reference.start_chapter,
+        reference.start_verse,
     ):
         return False
 
@@ -44,10 +47,14 @@ def is_valid_reference(reference: NormalizedReference) -> bool:
         return False
 
     start_verse_id: int = get_verse_id(
-        reference.book, reference.start_chapter, reference.start_verse
+        reference.book,
+        reference.start_chapter,
+        reference.start_verse,
     )
     end_verse_id: int = get_verse_id(
-        reference.book, reference.end_chapter, reference.end_verse
+        reference.book,
+        reference.end_chapter,
+        reference.end_verse,
     )
 
     return start_verse_id <= end_verse_id
@@ -55,7 +62,7 @@ def is_valid_reference(reference: NormalizedReference) -> bool:
 
 def is_valid_book(book: Book) -> bool:
     """
-    Checks to see if the given book is a valid book of the Bible
+    Check to see if the given book is a valid book of the Bible.
 
     :param book: a book of the Bible
     :type book: Book
@@ -67,8 +74,10 @@ def is_valid_book(book: Book) -> bool:
 
 def is_valid_chapter(book: Book, chapter: int) -> bool:
     """
-    Checks to see if the given Book is a valid book of the Bible; and, if so, checks
-    to see if the given chapter number is a valid chapter number for the given book
+    Check to see if the given Book is a valid book of the Bible.
+
+    If so, checks to see if the given chapter number is a valid chapter number for the
+    given book.
 
     :param book: a book of the Bible
     :type book: Book
@@ -83,19 +92,21 @@ def is_valid_chapter(book: Book, chapter: int) -> bool:
     if chapter is None or not isinstance(chapter, int):
         return False
 
-    chapter_list: Optional[List[int]] = MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER.get(book)
+    chapter_list: list[int] | None = MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER.get(book)
 
     return chapter_list is not None and 1 <= chapter <= len(chapter_list)
 
 
 def is_valid_verse(book: Book, chapter: int, verse: int) -> bool:
     """
-    Checks to see if the given :ref:`Book` is a valid book of the Bible,
-    then checks to see if the given chapter number is a valid chapter number for the given book,
-    then checks to see if the given verse number is a valid verse number for the given book and chapter
+    Check to see if the given Book is a valid book of the Bible.
+
+    Then checks to see if the given chapter number is a valid chapter number for the
+    given book, then checks to see if the given verse number is a valid verse number
+    for the given book and chapter.
 
     :param book: a book of the Bible
-    :type book: :ref:`Book`
+    :type book: Book
     :param chapter: a chapter number for the given book of the Bible
     :type chapter: int
     :param verse: a verse number for the given book and chapter
